@@ -25,6 +25,22 @@ pub fn lines_per_file(file: &File, n_files: usize) -> Option<(usize, usize)> {
     }
 }
 
+pub fn get_target_directory(file: &File) -> String {
+    format!(
+        "{}/{}",
+        current_dir().unwrap().display(),
+        file.base_name().unwrap()
+    )
+}
+
+pub fn gen_paths(file: &File, n_files: usize) -> Vec<String> {
+    let names = misc::gen_names(file, n_files);
+    names
+        .iter()
+        .map(|a| format!("{}/{}", get_target_directory(file), a))
+        .collect()
+}
+
 pub fn gen_names(file: &File, n_files: usize) -> Vec<String> {
     let mut result = Vec::<String>::new();
     let base_name = file.base_name().unwrap_or_else(|| {
@@ -37,3 +53,10 @@ pub fn gen_names(file: &File, n_files: usize) -> Vec<String> {
 
     result
 }
+
+#[macro_export]
+macro_rules! b_file {
+    ($f: expr) => {
+        $f.clone().lock().unwrap().deref_mut()
+    };
+}
